pub struct FromVecWithNulError { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
An error indicating that a nul byte was not in the expected position.
The vector used to create a CString must have one and only one nul byte,
positioned at the end.
This error is created by the CString::from_vec_with_nul method.
See its documentation for more.
Examples
use std::ffi::{CString, FromVecWithNulError};
let _: FromVecWithNulError = CString::from_vec_with_nul(b"f\0oo".to_vec()).unwrap_err();Implementations
1.58.0 · Sourceimpl FromVecWithNulError
impl FromVecWithNulError
1.58.0 · Sourcepub fn into_bytes(self) -> Vec<u8> ⓘ
pub fn into_bytes(self) -> Vec<u8> ⓘ
Returns the bytes that were attempted to convert to a CString.
This method is carefully constructed to avoid allocation. It will consume the error, moving out the bytes, so that a copy of the bytes does not need to be made.
Examples
Basic usage:
use std::ffi::CString;
// Some invalid bytes in a vector
let bytes = b"f\0oo".to_vec();
let value = CString::from_vec_with_nul(bytes.clone());
assert_eq!(bytes, value.unwrap_err().into_bytes());Trait Implementations
1.64.0 · Sourceimpl Clone for FromVecWithNulError
impl Clone for FromVecWithNulError
Sourcefn clone(&self) -> FromVecWithNulError
fn clone(&self) -> FromVecWithNulError
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read more1.64.0 · Sourceimpl Debug for FromVecWithNulError
impl Debug for FromVecWithNulError
1.58.0 · Sourceimpl Display for FromVecWithNulError
impl Display for FromVecWithNulError
1.58.0 · Sourceimpl Error for FromVecWithNulError
impl Error for FromVecWithNulError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()
1.64.0 · Sourceimpl PartialEq for FromVecWithNulError
impl PartialEq for FromVecWithNulError
impl Eq for FromVecWithNulError
impl StructuralPartialEq for FromVecWithNulError